# ![googly](docs/source/_static/logo.gif)
<!-- SPHINX-START -->
* googly (adjective) /ˈɡuɡli/
   1. (of the eyes) Bulging.
* googly (noun) /ˈɡuɡli/
   1. (cricket) A ball that spins from off to leg
   2. (python) **A simple unofficial Python API for many Google APIs**
* googly eye (noun) /ˈɡuɡli aɪ/
   1. craft supplies that resemble eyes
* googley (adjective) /ˈɡuɡəli/
   1. having qualities in line with the Google's corporate culture

[adapted from en.wiktionary.org](https://en.wiktionary.org/wiki/googly)

## Installation
[![PyPI version](https://badge.fury.io/py/googly.svg)](https://badge.fury.io/py/googly)

    sudo pip3 install googly

<!-- SPHINX-STOP -->

![GH action status](https://github.com/DLu/googly/actions/workflows/main.yaml/badge.svg)
[![codecov](https://codecov.io/gh/DLu/googly/graph/badge.svg?token=M11YQ62JK6)](https://codecov.io/gh/DLu/googly)

## Documentation

[![Documentation Status](https://readthedocs.org/projects/googly/badge/?version=latest)](https://googly.readthedocs.io/en/latest/?badge=latest)
[`http://googly.readthedocs.org/`](http://googly.readthedocs.org/)

![a buncha googly eyes](https://media3.giphy.com/media/v1.Y2lkPTc5MGI3NjExdWVsaWZ1cDZ0dzY2ZHlkdGJib2hieTdmeHp2azE3ZnlwYWhoOTlsMiZlcD12MV9pbnRlcm5hbF9naWZfYnlfaWQmY3Q9Zw/FkLMzWnIHxcs9WDJvf/giphy.gif)
